==> nocc-1.9.1.tbz: www/nocc/lang/ro.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ro.php 2378 2011-02-03 00:09:35Z siebrand $
 */
/** Romanian (Română)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Firilacroco
 * @author Minisarm
 * @author Nicu Buculei <nicubunu@yahoo.com>
 * @author Stelistcristi
 */

$lang_locale = 'ro_RO.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Nu ati introdus numele';
$err_passwd_empty = 'Nu ati introdus parola';
$alt_delete = 'Stergere mesaje selectate';
$alt_delete_one = 'Stergere mesaj';
$alt_new_msg = 'Mesaj nou';
$alt_reply = 'Raspuns';
$alt_reply_all = 'Raspuns tuturor';
$alt_forward = 'Redirectionare';
$alt_next = 'Următorul';
$alt_prev = 'Anteriorul';
$title_next_page = 'Următoarea pagină';
$title_prev_page = 'Precedenta pagină';
$title_next_msg = 'Mesaj urmator';
$title_prev_msg = 'Mesaj anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bun venit la %1$s';
$html_login = 'Autentificare';
$html_user_label = 'Utilizator:';
$html_passwd_label = 'Parola:';
$html_submit = 'Trimit';
$html_help = 'Ajutor';
$html_server_label = 'Server:';
$html_wrong = 'Numele sau parola sunt incorecte';
$html_retry = 'Alta incercare';
$html_remember = 'Ţine minte setările';
$html_lang_label = 'Limba:';
$html_msgperpage_label = 'Mesaje pe pagină:';
$html_preferences = 'Preferinte';
$html_full_name_label = 'Nume complet:';
$html_email_address_label = 'Adresa de e-mail:';
$html_bccself = 'Bcc self';
$html_hide_addresses = 'Ascunde adrese';
$html_outlook_quoting = 'Cotare in stil Outlook';
$html_reply_to = 'Raspuns';
$html_use_signature = 'Folosire semnatura';
$html_signature = 'Semnatura';
$html_signature_label = 'Semnătură:';
$html_prefs_updated = 'Actualizare preferinte';
$html_use_graphical_smilies = 'Folosiți zâmbărețele grafice';
$html_colored_quotes = 'Citate colorate';
$html_send_html_mail = 'Trimiteți e-mail în format HTML';
$html_folders = 'Foldere';
$html_folders_create_failed = 'Folderul nu poate fi creat!';
$html_folders_sub_failed = 'Nu se poate subscrie pe folder!';
$html_folders_rename_failed = 'Folderul nu poate fi redenumit!';
$html_folders_updated = 'Folderele s-au actualizat';
$html_folder_subscribe = 'Abonează-te la';
$html_folder_rename = 'Redenumește';
$html_folder_create = 'Creați un nou folder numit';
$html_folder_remove = 'Dezabonare de la';
$html_folder_delete = 'Ştergeți';
$html_folder_to = 'către';
$html_filter_remove = 'Ştergeți';
$html_filter_body = 'Corp mesaj';
$html_filter_subject = 'Subiect mesaj';
$html_filter_to = 'Câmpul „către”';
$html_filter_cc = 'Câmpul „cc”';
$html_filter_from = 'Câmpul „de la”';
$html_filter_change_tip = 'Pentru a schimba un filtru, pur și simplu suprascrieți-l.';
$html_reapply_filters = 'Reaplicați toate filtrele';
$html_filter_contains = 'conține';
$html_filter_name = 'Nume filtru';
$html_filter_action = 'Acțiune filtru';
$html_select_one = '--Alegeți una--';
$html_and = 'și';
$html_new_msg_in = 'Mesaje noi în';
$html_or = 'sau';
$html_move = 'Mutați';
$html_copy = 'Copiați';
$html_page = 'Pagina';
$html_view_header = 'Vizualizare header';
$html_remove_header = 'Ascundere header';
$html_inbox = 'Mesaje primite';
$html_new_msg = 'Mesaj Nou';
$html_reply = 'Raspuns';
$html_reply_short = 'Re:';
$html_reply_all = 'Raspuns tuturor';
$html_forward = 'Redirectionare';
$html_delete = 'Stergere';
$html_new = 'Nou';
$html_mark = 'Stergere';
$html_att_label = 'Fișier atașat:';
$html_unknown = '[necunoscut]';
$html_attach = 'Atasare';
$html_attach_forget = 'Trebuie atasat fisierul inainte de a trimite mesajul !';
$html_attach_delete = 'Stergere selectie';
$html_sort_by = 'Sortare dupa';
$html_sort = 'Sortare';
$html_from = 'De la';
$html_from_label = 'De la:';
$html_subject = 'Subiect';
$html_subject_label = 'Subiect';
$html_date = 'Data';
$html_date_label = 'Dată';
$html_sent_label = 'Trimis:';
$html_wrote = 'a scris';
$html_size = 'Marime';
$html_totalsize = 'Marime Totala';
$html_bytes = 'baiți';
$html_filename = 'Nume fisier';
$html_to = 'Catre';
$html_nosubject = 'Fara subiect';
$html_send = 'Trimitere';
$html_cancel = 'Renuntare';
$html_no_mail = 'Nici un mesaj.';
$html_logout = 'Iesire';
$html_msg = 'Mesaj';
$html_msgs = 'Mesaje';
$html_configuration = 'Serverul nu e corect configurat !';
$html_priority_label = 'Prioritate:';
$html_low = 'Mica';
$html_normal = 'Normala';
$html_high = 'Mare';
$html_select = 'Selectare';
$html_loading_image = 'Incarcare imagine';
$html_send_confirmed = 'Mesajul a fost acceptat pentru trnsmitere';
$html_no_sendaction = 'Nu a fost specificata nici o actiune. Incercati sa activati JavaScript.';
$html_error_occurred = 'Eroare';
$html_prefs_file_error = 'Nu se poate accesa fisierul de preferinte pentru scriere.';
$original_msg = '-- Mesaj original --';
$to_empty = 'Campul \'To\' nu poate fi gol !';
$html_smtp_error_no_conn = 'Nu se poate deschide conexiunea';
$html_smtp_error_unexpected = 'Raspuns neasteptate:';

==> nocc-1.9.3.tbz: www/nocc/lang/ro.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ro.php 2531 2012-03-01 15:52:20Z siebrand $
 */
/** Romanian (Română)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Firilacroco
 * @author Minisarm
 * @author Nicu Buculei <nicubunu@yahoo.com>
 * @author Stelistcristi
 */

$lang_locale = 'ro_RO.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Nu ati introdus numele';
$err_passwd_empty = 'Nu ati introdus parola';
$alt_delete = 'Stergere mesaje selectate';
$alt_delete_one = 'Stergere mesaj';
$alt_new_msg = 'Mesaj nou';
$alt_reply = 'Raspuns';
$alt_reply_all = 'Raspuns tuturor';
$alt_forward = 'Redirectionare';
$alt_next = 'Următorul';
$alt_prev = 'Anteriorul';
$title_next_page = 'Următoarea pagină';
$title_prev_page = 'Precedenta pagină';
$title_next_msg = 'Mesaj urmator';
$title_prev_msg = 'Mesaj anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bun venit la %1$s';
$html_login = 'Autentificare';
$html_user_label = 'Utilizator:';
$html_passwd_label = 'Parola:';
$html_submit = 'Trimit';
$html_help = 'Ajutor';
$html_server_label = 'Server:';
$html_wrong = 'Numele sau parola sunt incorecte';
$html_retry = 'Alta incercare';
$html_remember = 'Ţine minte setările';
$html_lang_label = 'Limba:';
$html_msgperpage_label = 'Mesaje pe pagină:';
$html_preferences = 'Preferinte';
$html_full_name_label = 'Nume complet:';
$html_email_address_label = 'Adresa de e-mail:';
$html_bccself = 'Bcc self';
$html_hide_addresses = 'Ascunde adrese';
$html_outlook_quoting = 'Cotare in stil Outlook';
$html_reply_to = 'Raspuns';
$html_use_signature = 'Folosire semnatura';
$html_signature = 'Semnatura';
$html_signature_label = 'Semnătură:';
$html_prefs_updated = 'Actualizare preferinte';
$html_use_graphical_smilies = 'Folosiți zâmbărețele grafice';
$html_colored_quotes = 'Citate colorate';
$html_send_html_mail = 'Trimiteți e-mail în format HTML';
$html_folders = 'Foldere';
$html_folders_create_failed = 'Folderul nu poate fi creat!';
$html_folders_sub_failed = 'Nu se poate subscrie pe folder!';
$html_folders_rename_failed = 'Folderul nu poate fi redenumit!';
$html_folders_updated = 'Folderele s-au actualizat';
$html_folder_subscribe = 'Abonează-te la';
$html_folder_rename = 'Redenumește';
$html_folder_create = 'Creați un nou folder numit';
$html_folder_remove = 'Dezabonare de la';
$html_folder_delete = 'Ştergeți';
$html_folder_to = 'către';
$html_filter_remove = 'Ştergeți';
$html_filter_body = 'Corp mesaj';
$html_filter_subject = 'Subiect mesaj';
$html_filter_to = 'Câmpul „către”';
$html_filter_cc = 'Câmpul „cc”';
$html_filter_from = 'Câmpul „de la”';
$html_filter_change_tip = 'Pentru a schimba un filtru, pur și simplu suprascrieți-l.';
$html_reapply_filters = 'Reaplicați toate filtrele';
$html_filter_contains = 'conține';
$html_filter_name = 'Nume filtru';
$html_filter_action = 'Acțiune filtru';
$html_select_one = '--Alegeți una--';
$html_and = 'și';
$html_new_msg_in = 'Mesaje noi în';
$html_or = 'sau';
$html_move = 'Mutați';
$html_copy = 'Copiați';
$html_page = 'Pagina';
$html_view_header = 'Vizualizare header';
$html_remove_header = 'Ascundere header';
$html_inbox = 'Mesaje primite';
$html_new_msg = 'Mesaj Nou';
$html_reply = 'Raspuns';
$html_reply_short = 'Re:';
$html_reply_all = 'Raspuns tuturor';
$html_forward = 'Redirectionare';
$html_delete = 'Stergere';
$html_new = 'Nou';
$html_mark = 'Stergere';
$html_att_label = 'Fișier atașat:';
$html_unknown = '[necunoscut]';
$html_attach = 'Atasare';
$html_attach_forget = 'Trebuie atasat fisierul inainte de a trimite mesajul !';
$html_attach_delete = 'Stergere selectie';
$html_sort_by = 'Sortare după';
$html_sort = 'Sortare';
$html_from = 'De la';
$html_from_label = 'De la:';
$html_subject = 'Subiect';
$html_subject_label = 'Subiect';
$html_date = 'Data';
$html_date_label = 'Dată';
$html_sent_label = 'Trimis:';
$html_wrote = 'a scris';
$html_size = 'Marime';
$html_totalsize = 'Marime Totala';
$html_bytes = 'baiți';
$html_filename = 'Nume fisier';
$html_to = 'Către';
$html_nosubject = 'Fara subiect';
$html_send = 'Trimitere';
$html_cancel = 'Renuntare';
$html_no_mail = 'Nici un mesaj.';
$html_logout = 'Iesire';
$html_msg = 'Mesaj';
$html_msgs = 'Mesaje';
$html_configuration = 'Serverul nu e corect configurat !';
$html_priority_label = 'Prioritate:';
$html_low = 'Mica';
$html_normal = 'Normala';
$html_high = 'Mare';
$html_select = 'Selectare';
$html_loading_image = 'Incarcare imagine';
$html_send_confirmed = 'Mesajul a fost acceptat pentru trnsmitere';
$html_no_sendaction = 'Nu a fost specificata nici o actiune. Incercati sa activati JavaScript.';
$html_error_occurred = 'Eroare';
$html_prefs_file_error = 'Nu se poate accesa fisierul de preferinte pentru scriere.';
$original_msg = '-- Mesaj original --';
$to_empty = 'Campul \'To\' nu poate fi gol !';
$html_smtp_error_no_conn = 'Nu se poate deschide conexiunea';
$html_smtp_error_unexpected = 'Raspuns neasteptate:';
